@@ -261,6 +261,7 @@ thDelay=1,  thVar=NULL, mTh=1, starting=NULL, innov=rmnorm(n, mean=0, varcov=var
 #'simulate/bootstrap a VAR, \code{\link{TVECM.sim}} to simulate/bootstrap a
 #'TVECM.
 #'@keywords ts bootstrap
+#'@export
 #'@examples
 #'
 #'##simulate VAR as in Enders 2004, p 268
@@ -318,6 +319,7 @@ thVar=NULL, mTh=1, starting=NULL, innov=rmnorm(n, mean=0, varcov=varcov), varcov
 #'simulate/bootstrap a VAR, \code{\link{TVECM.sim}} to simulate/bootstrap a
 #'TVECM.
 #'@keywords ts bootstrap
+#'@export
 #'@examples
 #'
 #'
@@ -340,6 +342,7 @@ innov=rmnorm(n, mean=0, varcov=varcov), varcov=diag(1,nrow(B)), show.parMat=FALS
 }
 
 #' @rdname TVAR.boot
+#' @export
 VAR.boot <- function(VARobject, innov, seed, ...){
   if(!inherits(VARobject, "VAR")) stop("Please provide an object of class 'VAR' generated by lineVar()")
   if(attr(VARobject, "varsLevel")!="level") stop("Does not work with VAR in diff or ADf specification")
@@ -380,7 +383,7 @@ ns<-nrow(serie)
 comp_tvar_sim <- function(mod, serie){
   ns <- nrow(serie)
   sim_mod <- TVAR.sim(B=coef(mod), lag=mod$lag, include=mod$include,nthresh=0, n=ns-mod$lag, innov=residuals(mod), starting=serie[1:mod$lag,,drop=FALSE])
-  all.equal(sim_mod, as.matrix(serie)[-c(1:mod$lag),], check.attr=FALSE)
+  all.equal(sim_mod, as.matrix(serie)[-c(1:mod$lag),], check.attributes=FALSE)
 }
 
 
